/* libvirt-broker.c generated by valac 0.22.1.2-49127, the Vala compiler
 * generated from libvirt-broker.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gio/gio.h>
#include <libcommon.h>
#include <stdlib.h>
#include <string.h>
#include <libvirt-gobject/libvirt-gobject.h>
#include <clutter/clutter.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <gtk/gtk.h>
#include <clutter-gtk/clutter-gtk.h>
#include <libvirt-gconfig/libvirt-gconfig.h>


#define BOXES_TYPE_BROKER (boxes_broker_get_type ())
#define BOXES_BROKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_BROKER, BoxesBroker))
#define BOXES_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_BROKER, BoxesBrokerClass))
#define BOXES_IS_BROKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_BROKER))
#define BOXES_IS_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_BROKER))
#define BOXES_BROKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_BROKER, BoxesBrokerClass))

typedef struct _BoxesBroker BoxesBroker;
typedef struct _BoxesBrokerClass BoxesBrokerClass;
typedef struct _BoxesBrokerPrivate BoxesBrokerPrivate;

#define BOXES_TYPE_LIBVIRT_BROKER (boxes_libvirt_broker_get_type ())
#define BOXES_LIBVIRT_BROKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_BROKER, BoxesLibvirtBroker))
#define BOXES_LIBVIRT_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_BROKER, BoxesLibvirtBrokerClass))
#define BOXES_IS_LIBVIRT_BROKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_BROKER))
#define BOXES_IS_LIBVIRT_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_BROKER))
#define BOXES_LIBVIRT_BROKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_BROKER, BoxesLibvirtBrokerClass))

typedef struct _BoxesLibvirtBroker BoxesLibvirtBroker;
typedef struct _BoxesLibvirtBrokerClass BoxesLibvirtBrokerClass;
typedef struct _BoxesLibvirtBrokerPrivate BoxesLibvirtBrokerPrivate;
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UI, BoxesUIClass))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_IS_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UI))
#define BOXES_UI_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UI, BoxesUIClass))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIClass BoxesUIClass;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;

#define BOXES_TYPE_LIBVIRT_MACHINE (boxes_libvirt_machine_get_type ())
#define BOXES_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine))
#define BOXES_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))
#define BOXES_IS_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_IS_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_LIBVIRT_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))

typedef struct _BoxesLibvirtMachine BoxesLibvirtMachine;
typedef struct _BoxesLibvirtMachineClass BoxesLibvirtMachineClass;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;
typedef struct _BoxesUIPrivate BoxesUIPrivate;
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;

#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define TYPE_PROPERTY_CREATION_FLAG (property_creation_flag_get_type ())

#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;
typedef struct _BoxesMachinePrivate BoxesMachinePrivate;

#define BOXES_MACHINE_TYPE_CONNECT_FLAGS (boxes_machine_connect_flags_get_type ())
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_CLUTTER_WIDGET (boxes_clutter_widget_get_type ())
#define BOXES_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidget))
#define BOXES_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))
#define BOXES_IS_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_IS_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_CLUTTER_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))

typedef struct _BoxesClutterWidget BoxesClutterWidget;
typedef struct _BoxesClutterWidgetClass BoxesClutterWidgetClass;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_REVEALER (boxes_revealer_get_type ())
#define BOXES_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_REVEALER, BoxesRevealer))
#define BOXES_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_REVEALER, BoxesRevealerClass))
#define BOXES_IS_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_REVEALER))
#define BOXES_IS_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_REVEALER))
#define BOXES_REVEALER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_REVEALER, BoxesRevealerClass))

typedef struct _BoxesRevealer BoxesRevealer;
typedef struct _BoxesRevealerClass BoxesRevealerClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;

#define BOXES_TYPE_COLLECTION_FILTER (boxes_collection_filter_get_type ())
#define BOXES_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilter))
#define BOXES_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))
#define BOXES_IS_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_IS_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_COLLECTION_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))

typedef struct _BoxesCollectionFilter BoxesCollectionFilter;
typedef struct _BoxesCollectionFilterClass BoxesCollectionFilterClass;

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define BOXES_TYPE_VM_CREATOR (boxes_vm_creator_get_type ())
#define BOXES_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreator))
#define BOXES_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))
#define BOXES_IS_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_VM_CREATOR))
#define BOXES_IS_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_VM_CREATOR))
#define BOXES_VM_CREATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))

typedef struct _BoxesVMCreator BoxesVMCreator;
typedef struct _BoxesVMCreatorClass BoxesVMCreatorClass;
#define _boxes_vm_creator_unref0(var) ((var == NULL) ? NULL : (var = (boxes_vm_creator_unref (var), NULL)))

#define BOXES_TYPE_VM_IMPORTER (boxes_vm_importer_get_type ())
#define BOXES_VM_IMPORTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_VM_IMPORTER, BoxesVMImporter))
#define BOXES_VM_IMPORTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_VM_IMPORTER, BoxesVMImporterClass))
#define BOXES_IS_VM_IMPORTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_VM_IMPORTER))
#define BOXES_IS_VM_IMPORTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_VM_IMPORTER))
#define BOXES_VM_IMPORTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_VM_IMPORTER, BoxesVMImporterClass))

typedef struct _BoxesVMImporter BoxesVMImporter;
typedef struct _BoxesVMImporterClass BoxesVMImporterClass;

#define BOXES_TYPE_LIBVIRT_SYSTEM_VM_IMPORTER (boxes_libvirt_system_vm_importer_get_type ())
#define BOXES_LIBVIRT_SYSTEM_VM_IMPORTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_SYSTEM_VM_IMPORTER, BoxesLibvirtSystemVMImporter))
#define BOXES_LIBVIRT_SYSTEM_VM_IMPORTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_SYSTEM_VM_IMPORTER, BoxesLibvirtSystemVMImporterClass))
#define BOXES_IS_LIBVIRT_SYSTEM_VM_IMPORTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_SYSTEM_VM_IMPORTER))
#define BOXES_IS_LIBVIRT_SYSTEM_VM_IMPORTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_SYSTEM_VM_IMPORTER))
#define BOXES_LIBVIRT_SYSTEM_VM_IMPORTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_SYSTEM_VM_IMPORTER, BoxesLibvirtSystemVMImporterClass))

typedef struct _BoxesLibvirtSystemVMImporter BoxesLibvirtSystemVMImporter;
typedef struct _BoxesLibvirtSystemVMImporterClass BoxesLibvirtSystemVMImporterClass;
typedef struct _Block21Data Block21Data;
#define __vala_GVirStoragePoolInfo_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirStoragePoolInfo_free (var), NULL)))
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))
typedef struct _BoxesLibvirtBrokerAddSourceData BoxesLibvirtBrokerAddSourceData;

struct _BoxesBroker {
	GObject parent_instance;
	BoxesBrokerPrivate * priv;
};

struct _BoxesBrokerClass {
	GObjectClass parent_class;
	void (*add_source) (BoxesBroker* self, BoxesCollectionSource* source, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*add_source_finish) (BoxesBroker* self, GAsyncResult* _res_);
};

struct _BoxesLibvirtBroker {
	BoxesBroker parent_instance;
	BoxesLibvirtBrokerPrivate * priv;
};

struct _BoxesLibvirtBrokerClass {
	BoxesBrokerClass parent_class;
};

struct _BoxesLibvirtBrokerPrivate {
	GHashTable* connections;
};

struct _BoxesUI {
	GObject parent_instance;
	BoxesUIPrivate * priv;
};

struct _BoxesUIClass {
	GObjectClass parent_class;
	void (*ui_state_changed) (BoxesUI* self);
	ClutterActor* (*get_actor) (BoxesUI* self);
};

struct _BoxesCollectionItem {
	BoxesUI parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	BoxesUIClass parent_class;
	gint (*compare) (BoxesCollectionItem* self, BoxesCollectionItem* other);
};

typedef enum  {
	BOXES_PROPERTIES_PAGE_LOGIN,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DISPLAY,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

typedef enum  {
	PROPERTY_CREATION_FLAG_NONE = 1 << 0,
	PROPERTY_CREATION_FLAG_NO_USB = 1 << 1
} PropertyCreationFlag;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
};

typedef enum  {
	BOXES_MACHINE_CONNECT_FLAGS_NONE = 0,
	BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE = 1 << 0
} BoxesMachineConnectFlags;

struct _BoxesMachine {
	BoxesCollectionItem parent_instance;
	BoxesMachinePrivate * priv;
	BoxesCollectionSource* source;
	BoxesBoxConfig* config;
	gboolean stay_on_display;
	gboolean suspend_at_exit;
	gboolean deleted;
};

struct _BoxesMachineClass {
	BoxesCollectionItemClass parent_class;
	void (*save_real) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*save_real_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*take_screenshot) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GdkPixbuf* (*take_screenshot_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	GList* (*get_properties) (BoxesMachine* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
	void (*connect_display) (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*connect_display_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*disconnect_display) (BoxesMachine* self);
	void (*delete) (BoxesMachine* self, gboolean by_user);
};

struct _BoxesApp {
	BoxesUI parent_instance;
	BoxesAppPrivate * priv;
	GtkApplicationWindow* window;
	GtkNotebook* notebook;
	BoxesClutterWidget* embed;
	ClutterStage* stage;
	ClutterBinLayout* stage_bin;
	ClutterActor* overlay_bin_actor;
	ClutterBinLayout* overlay_bin;
	BoxesCollectionItem* current_item;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesRevealer* sidebar_revealer;
	BoxesRevealer* searchbar_revealer;
	BoxesSidebar* sidebar;
	BoxesSelectionbar* selectionbar;
	guint duration;
	GSettings* settings;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	BoxesCollection* collection;
	BoxesCollectionFilter* filter;
	BoxesCollectionView* view;
};

struct _BoxesAppClass {
	BoxesUIClass parent_class;
};

struct _Block21Data {
	int _ref_count_;
	BoxesLibvirtBroker * self;
	BoxesCollectionSource* source;
	gpointer _async_data_;
};

struct _BoxesLibvirtBrokerAddSourceData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesLibvirtBroker* self;
	BoxesCollectionSource* source;
	Block21Data* _data21_;
	BoxesCollectionSource* _tmp0_;
	GHashTable* _tmp1_;
	BoxesCollectionSource* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gconstpointer _tmp6_;
	gboolean _tmp7_;
	GVirConnection* connection;
	BoxesCollectionSource* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
	gchar* _tmp11_;
	GVirConnection* _tmp12_;
	GVirConnection* _tmp13_;
	GVirConnection* _tmp14_;
	GVirConnection* _tmp15_;
	GVirConnection* _tmp16_;
	GVirStoragePool* pool;
	GVirConnection* _tmp17_;
	GVirStoragePool* _tmp18_;
	GVirStoragePool* _tmp19_;
	GVirStoragePoolInfo* _tmp20_;
	GVirStoragePool* _tmp21_;
	GVirStoragePoolInfo* _tmp22_;
	GVirStoragePoolInfo* _tmp23_;
	GVirStoragePoolState _tmp24_;
	gboolean _tmp25_;
	GVirStoragePool* _tmp26_;
	GVirStoragePool* _tmp27_;
	GError* _error_;
	GError* _tmp28_;
	const gchar* _tmp29_;
	GHashTable* _tmp30_;
	BoxesCollectionSource* _tmp31_;
	gchar* _tmp32_;
	gchar* _tmp33_;
	GVirConnection* _tmp34_;
	GVirConnection* _tmp35_;
	GVirConnection* _tmp36_;
	GList* _tmp37_;
	GList* domain_collection;
	GList* domain_it;
	GVirDomain* _tmp38_;
	GVirDomain* domain;
	BoxesCollectionSource* _tmp39_;
	GVirConnection* _tmp40_;
	GVirDomain* _tmp41_;
	GVirConnection* _tmp42_;
	GVirConnection* _tmp43_;
	BoxesCollectionSource* _tmp44_;
	GError * _inner_error_;
};


static gpointer boxes_libvirt_broker_parent_class = NULL;
static BoxesLibvirtBroker* boxes_libvirt_broker_broker;
static BoxesLibvirtBroker* boxes_libvirt_broker_broker = NULL;
extern BoxesApp* boxes_app_app;

GType boxes_broker_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_broker_get_type (void) G_GNUC_CONST;
#define BOXES_LIBVIRT_BROKER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_LIBVIRT_BROKER, BoxesLibvirtBrokerPrivate))
enum  {
	BOXES_LIBVIRT_BROKER_DUMMY_PROPERTY
};
BoxesLibvirtBroker* boxes_libvirt_broker_get_default (void);
static BoxesLibvirtBroker* boxes_libvirt_broker_new (void);
static BoxesLibvirtBroker* boxes_libvirt_broker_construct (GType object_type);
BoxesBroker* boxes_broker_construct (GType object_type);
static void _g_free0_ (gpointer var);
static void _g_object_unref0_ (gpointer var);
GVirConnection* boxes_libvirt_broker_get_connection (BoxesLibvirtBroker* self, const gchar* name);
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_machine_get_type (void) G_GNUC_CONST;
BoxesLibvirtMachine* boxes_libvirt_broker_add_domain (BoxesLibvirtBroker* self, BoxesCollectionSource* source, GVirConnection* connection, GVirDomain* domain, GError** error);
BoxesLibvirtMachine* boxes_libvirt_machine_new (BoxesCollectionSource* source, GVirConnection* connection, GVirDomain* domain, GError** error);
BoxesLibvirtMachine* boxes_libvirt_machine_construct (GType object_type, BoxesCollectionSource* source, GVirConnection* connection, GVirDomain* domain, GError** error);
GType boxes_app_get_type (void) G_GNUC_CONST;
GVirConnection* boxes_app_get_default_connection (BoxesApp* self);
GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType property_creation_flag_get_type (void) G_GNUC_CONST;
GType boxes_property_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_machine_connect_flags_get_type (void) G_GNUC_CONST;
GType boxes_clutter_widget_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_revealer_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
GType boxes_collection_filter_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
void boxes_collection_add_item (BoxesCollection* self, BoxesCollectionItem* item);
static void boxes_libvirt_broker_try_add_new_domain (BoxesLibvirtBroker* self, BoxesCollectionSource* source, GVirConnection* connection, GVirDomain* domain);
static void boxes_libvirt_broker_try_add_existing_domain (BoxesLibvirtBroker* self, BoxesCollectionSource* source, GVirConnection* connection, GVirDomain* domain);
GVirConfigDomain* boxes_libvirt_machine_get_domain_config (BoxesLibvirtMachine* self);
gboolean boxes_vm_configurator_is_install_config (GVirConfigDomain* domain);
gboolean boxes_vm_configurator_is_live_config (GVirConfigDomain* domain);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
BoxesVMCreator* boxes_vm_creator_new_for_install_completion (BoxesLibvirtMachine* machine);
BoxesVMCreator* boxes_vm_creator_construct_for_install_completion (GType object_type, BoxesLibvirtMachine* machine);
gpointer boxes_vm_creator_ref (gpointer instance);
void boxes_vm_creator_unref (gpointer instance);
GParamSpec* boxes_param_spec_vm_creator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void boxes_value_set_vm_creator (GValue* value, gpointer v_object);
void boxes_value_take_vm_creator (GValue* value, gpointer v_object);
gpointer boxes_value_get_vm_creator (const GValue* value);
GType boxes_vm_creator_get_type (void) G_GNUC_CONST;
gboolean boxes_vm_configurator_is_import_config (GVirConfigDomain* domain);
BoxesVMImporter* boxes_vm_importer_new_for_import_completion (BoxesLibvirtMachine* machine);
BoxesVMImporter* boxes_vm_importer_construct_for_import_completion (GType object_type, BoxesLibvirtMachine* machine);
GType boxes_vm_importer_get_type (void) G_GNUC_CONST;
gboolean boxes_vm_configurator_is_libvirt_system_import_config (GVirConfigDomain* domain);
BoxesLibvirtSystemVMImporter* boxes_libvirt_system_vm_importer_new_for_import_completion (BoxesLibvirtMachine* machine);
BoxesLibvirtSystemVMImporter* boxes_libvirt_system_vm_importer_construct_for_import_completion (GType object_type, BoxesLibvirtMachine* machine);
GType boxes_libvirt_system_vm_importer_get_type (void) G_GNUC_CONST;
static void boxes_libvirt_broker_real_add_source_data_free (gpointer _data);
static void boxes_libvirt_broker_real_add_source (BoxesBroker* base, BoxesCollectionSource* source, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean boxes_libvirt_broker_real_add_source_co (BoxesLibvirtBrokerAddSourceData* _data_);
static Block21Data* block21_data_ref (Block21Data* _data21_);
static void block21_data_unref (void * _userdata_);
static void boxes_libvirt_broker_add_source_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
GVirStoragePool* boxes_get_storage_pool (GVirConnection* connection);
static void _vala_GVirStoragePoolInfo_free (GVirStoragePoolInfo* self);
static void _g_list_free__g_object_unref0_ (GList* self);
static void __lambda64_ (BoxesLibvirtBroker* self, GVirConnection* connection, GVirDomain* domain);
void boxes_app_delete_machine (BoxesApp* self, BoxesMachine* machine, gboolean by_user);
static void ___lambda64__gvir_connection_domain_removed (GVirConnection* _sender, GVirDomain* dom, gpointer self);
static void __lambda65_ (Block21Data* _data21_, GVirConnection* connection, GVirDomain* domain);
static void ___lambda65__gvir_connection_domain_added (GVirConnection* _sender, GVirDomain* dom, gpointer self);
void boxes_broker_add_source (BoxesBroker* self, BoxesCollectionSource* source, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_broker_add_source_finish (BoxesBroker* self, GAsyncResult* _res_);
static void boxes_libvirt_broker_finalize (GObject* obj);


static gpointer _g_object_ref0 (gpointer self) {
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	return self ? g_object_ref (self) : NULL;
#line 586 "libvirt-broker.c"
}


BoxesLibvirtBroker* boxes_libvirt_broker_get_default (void) {
	BoxesLibvirtBroker* result = NULL;
	BoxesLibvirtBroker* _tmp0_ = NULL;
	BoxesLibvirtBroker* _tmp2_ = NULL;
	BoxesLibvirtBroker* _tmp3_ = NULL;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp0_ = boxes_libvirt_broker_broker;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	if (_tmp0_ == NULL) {
#line 599 "libvirt-broker.c"
		BoxesLibvirtBroker* _tmp1_ = NULL;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_tmp1_ = boxes_libvirt_broker_new ();
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_g_object_unref0 (boxes_libvirt_broker_broker);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		boxes_libvirt_broker_broker = _tmp1_;
#line 607 "libvirt-broker.c"
	}
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp2_ = boxes_libvirt_broker_broker;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	result = _tmp3_;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	return result;
#line 617 "libvirt-broker.c"
}


static void _g_free0_ (gpointer var) {
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	var = (g_free (var), NULL);
#line 624 "libvirt-broker.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 631 "libvirt-broker.c"
}


static BoxesLibvirtBroker* boxes_libvirt_broker_construct (GType object_type) {
	BoxesLibvirtBroker * self = NULL;
	GHashFunc _tmp0_ = NULL;
	GEqualFunc _tmp1_ = NULL;
	GHashTable* _tmp2_ = NULL;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	self = (BoxesLibvirtBroker*) boxes_broker_construct (object_type);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp0_ = g_str_hash;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp1_ = g_str_equal;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp2_ = g_hash_table_new_full (_tmp0_, _tmp1_, _g_free0_, _g_object_unref0_);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_hash_table_unref0 (self->priv->connections);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	self->priv->connections = _tmp2_;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	return self;
#line 654 "libvirt-broker.c"
}


static BoxesLibvirtBroker* boxes_libvirt_broker_new (void) {
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	return boxes_libvirt_broker_construct (BOXES_TYPE_LIBVIRT_BROKER);
#line 661 "libvirt-broker.c"
}


GVirConnection* boxes_libvirt_broker_get_connection (BoxesLibvirtBroker* self, const gchar* name) {
	GVirConnection* result = NULL;
	BoxesLibvirtBroker* _tmp0_ = NULL;
	BoxesLibvirtBroker* _tmp1_ = NULL;
	GHashTable* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gconstpointer _tmp4_ = NULL;
	GVirConnection* _tmp5_ = NULL;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp0_ = boxes_libvirt_broker_broker;
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_return_if_fail (_tmp0_ != NULL);
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp1_ = boxes_libvirt_broker_broker;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp2_ = _tmp1_->priv->connections;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp3_ = name;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp4_ = g_hash_table_lookup (_tmp2_, _tmp3_);
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp5_ = _g_object_ref0 ((GVirConnection*) _tmp4_);
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	result = _tmp5_;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	return result;
#line 695 "libvirt-broker.c"
}


BoxesLibvirtMachine* boxes_libvirt_broker_add_domain (BoxesLibvirtBroker* self, BoxesCollectionSource* source, GVirConnection* connection, GVirDomain* domain, GError** error) {
	BoxesLibvirtMachine* result = NULL;
	BoxesLibvirtBroker* _tmp0_ = NULL;
	BoxesLibvirtMachine* machine = NULL;
	GVirDomain* _tmp1_ = NULL;
	gconstpointer _tmp2_ = NULL;
	BoxesLibvirtMachine* _tmp3_ = NULL;
	BoxesLibvirtMachine* _tmp4_ = NULL;
	BoxesLibvirtMachine* _tmp5_ = NULL;
	BoxesCollectionSource* _tmp6_ = NULL;
	GVirConnection* _tmp7_ = NULL;
	GVirDomain* _tmp8_ = NULL;
	BoxesLibvirtMachine* _tmp9_ = NULL;
	BoxesLibvirtMachine* _tmp10_ = NULL;
	GVirConnection* _tmp11_ = NULL;
	BoxesApp* _tmp12_ = NULL;
	GVirConnection* _tmp13_ = NULL;
	GVirConnection* _tmp14_ = NULL;
	GVirConnection* _tmp15_ = NULL;
	BoxesApp* _tmp16_ = NULL;
	BoxesCollection* _tmp17_ = NULL;
	BoxesLibvirtMachine* _tmp18_ = NULL;
	GVirDomain* _tmp19_ = NULL;
	BoxesLibvirtMachine* _tmp20_ = NULL;
	BoxesLibvirtMachine* _tmp21_ = NULL;
	GError * _inner_error_ = NULL;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_return_val_if_fail (source != NULL, NULL);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_return_val_if_fail (connection != NULL, NULL);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_return_val_if_fail (domain != NULL, NULL);
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp0_ = boxes_libvirt_broker_broker;
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_return_if_fail (_tmp0_ != NULL);
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp1_ = domain;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp2_ = g_object_get_data ((GObject*) _tmp1_, "machine");
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp3_ = _g_object_ref0 ((BoxesLibvirtMachine*) _tmp2_);
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	machine = _tmp3_;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp4_ = machine;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	if (_tmp4_ != NULL) {
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		result = machine;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		return result;
#line 753 "libvirt-broker.c"
	}
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp6_ = source;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp7_ = connection;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp8_ = domain;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp9_ = boxes_libvirt_machine_new (_tmp6_, _tmp7_, _tmp8_, &_inner_error_);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp5_ = _tmp9_;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	if (_inner_error_ != NULL) {
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_propagate_error (error, _inner_error_);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_g_object_unref0 (machine);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		return NULL;
#line 773 "libvirt-broker.c"
	}
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_object_unref0 (machine);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	machine = _tmp5_;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp10_ = machine;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp11_ = connection;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp12_ = boxes_app_app;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp13_ = boxes_app_get_default_connection (_tmp12_);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp14_ = _tmp13_;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp15_ = _tmp14_;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	((BoxesMachine*) _tmp10_)->suspend_at_exit = _tmp11_ == _tmp15_;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_object_unref0 (_tmp15_);
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp16_ = boxes_app_app;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp17_ = _tmp16_->collection;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp18_ = machine;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	boxes_collection_add_item (_tmp17_, (BoxesCollectionItem*) _tmp18_);
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp19_ = domain;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp20_ = machine;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp21_ = _g_object_ref0 (_tmp20_);
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_object_set_data_full ((GObject*) _tmp19_, "machine", _tmp21_, g_object_unref);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	result = machine;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	return result;
#line 815 "libvirt-broker.c"
}


static void boxes_libvirt_broker_try_add_new_domain (BoxesLibvirtBroker* self, BoxesCollectionSource* source, GVirConnection* connection, GVirDomain* domain) {
	GError * _inner_error_ = NULL;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_return_if_fail (self != NULL);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_return_if_fail (source != NULL);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_return_if_fail (connection != NULL);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_return_if_fail (domain != NULL);
#line 829 "libvirt-broker.c"
	{
		BoxesCollectionSource* _tmp0_ = NULL;
		GVirConnection* _tmp1_ = NULL;
		GVirDomain* _tmp2_ = NULL;
		BoxesLibvirtMachine* _tmp3_ = NULL;
		BoxesLibvirtMachine* _tmp4_ = NULL;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_tmp0_ = source;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_tmp1_ = connection;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_tmp2_ = domain;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_tmp3_ = boxes_libvirt_broker_add_domain (self, _tmp0_, _tmp1_, _tmp2_, &_inner_error_);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_tmp4_ = _tmp3_;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_g_object_unref0 (_tmp4_);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		if (_inner_error_ != NULL) {
#line 850 "libvirt-broker.c"
			goto __catch12_g_error;
		}
	}
	goto __finally12;
	__catch12_g_error:
	{
		GError* _error_ = NULL;
		BoxesCollectionSource* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		GError* _tmp9_ = NULL;
		const gchar* _tmp10_ = NULL;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_error_ = _inner_error_;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_inner_error_ = NULL;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_tmp5_ = source;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_tmp6_ = boxes_collection_source_get_name (_tmp5_);
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_tmp7_ = _tmp6_;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_tmp8_ = _tmp7_;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_tmp9_ = _error_;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_tmp10_ = _tmp9_->message;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_warning ("libvirt-broker.vala:46: Failed to create source '%s': %s", _tmp8_, _tmp10_);
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_g_free0 (_tmp8_);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_g_error_free0 (_error_);
#line 886 "libvirt-broker.c"
	}
	__finally12:
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	if (_inner_error_ != NULL) {
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_clear_error (&_inner_error_);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		return;
#line 897 "libvirt-broker.c"
	}
}


static void boxes_libvirt_broker_try_add_existing_domain (BoxesLibvirtBroker* self, BoxesCollectionSource* source, GVirConnection* connection, GVirDomain* domain) {
	GError * _inner_error_ = NULL;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_return_if_fail (self != NULL);
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_return_if_fail (source != NULL);
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_return_if_fail (connection != NULL);
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_return_if_fail (domain != NULL);
#line 912 "libvirt-broker.c"
	{
		BoxesLibvirtMachine* machine = NULL;
		BoxesCollectionSource* _tmp0_ = NULL;
		GVirConnection* _tmp1_ = NULL;
		GVirDomain* _tmp2_ = NULL;
		BoxesLibvirtMachine* _tmp3_ = NULL;
		GVirConfigDomain* config = NULL;
		GVirConfigDomain* _tmp4_ = NULL;
		GVirConfigDomain* _tmp5_ = NULL;
		GVirConfigDomain* _tmp6_ = NULL;
		gboolean _tmp7_ = FALSE;
		GVirConfigDomain* _tmp8_ = NULL;
		gboolean _tmp9_ = FALSE;
		gboolean _tmp12_ = FALSE;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_tmp0_ = source;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_tmp1_ = connection;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_tmp2_ = domain;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_tmp3_ = boxes_libvirt_broker_add_domain (self, _tmp0_, _tmp1_, _tmp2_, &_inner_error_);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		machine = _tmp3_;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		if (_inner_error_ != NULL) {
#line 939 "libvirt-broker.c"
			goto __catch13_g_error;
		}
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_tmp4_ = boxes_libvirt_machine_get_domain_config (machine);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_tmp5_ = _tmp4_;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_tmp6_ = _g_object_ref0 (_tmp5_);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		config = _tmp6_;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_tmp8_ = config;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_tmp9_ = boxes_vm_configurator_is_install_config (_tmp8_);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		if (_tmp9_) {
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_tmp7_ = TRUE;
#line 958 "libvirt-broker.c"
		} else {
			GVirConfigDomain* _tmp10_ = NULL;
			gboolean _tmp11_ = FALSE;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_tmp10_ = config;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_tmp11_ = boxes_vm_configurator_is_live_config (_tmp10_);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_tmp7_ = _tmp11_;
#line 968 "libvirt-broker.c"
		}
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_tmp12_ = _tmp7_;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		if (_tmp12_) {
#line 974 "libvirt-broker.c"
			const gchar* _tmp13_ = NULL;
			const gchar* _tmp14_ = NULL;
			BoxesVMCreator* _tmp15_ = NULL;
			BoxesVMCreator* _tmp16_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_tmp13_ = boxes_collection_item_get_name ((BoxesCollectionItem*) machine);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_tmp14_ = _tmp13_;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			g_debug ("libvirt-broker.vala:58: Continuing installation/live session for '%s'," \
" ..", _tmp14_);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_tmp15_ = boxes_vm_creator_new_for_install_completion (machine);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_tmp16_ = _tmp15_;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_boxes_vm_creator_unref0 (_tmp16_);
#line 991 "libvirt-broker.c"
		} else {
			GVirConfigDomain* _tmp17_ = NULL;
			gboolean _tmp18_ = FALSE;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_tmp17_ = config;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_tmp18_ = boxes_vm_configurator_is_import_config (_tmp17_);
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			if (_tmp18_) {
#line 1001 "libvirt-broker.c"
				const gchar* _tmp19_ = NULL;
				const gchar* _tmp20_ = NULL;
				BoxesVMImporter* _tmp21_ = NULL;
				BoxesVMImporter* _tmp22_ = NULL;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_tmp19_ = boxes_collection_item_get_name ((BoxesCollectionItem*) machine);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_tmp20_ = _tmp19_;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				g_debug ("libvirt-broker.vala:61: Continuing import of '%s', ..", _tmp20_);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_tmp21_ = boxes_vm_importer_new_for_import_completion (machine);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_tmp22_ = _tmp21_;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_boxes_vm_creator_unref0 (_tmp22_);
#line 1018 "libvirt-broker.c"
			} else {
				GVirConfigDomain* _tmp23_ = NULL;
				gboolean _tmp24_ = FALSE;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_tmp23_ = config;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_tmp24_ = boxes_vm_configurator_is_libvirt_system_import_config (_tmp23_);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				if (_tmp24_) {
#line 1028 "libvirt-broker.c"
					const gchar* _tmp25_ = NULL;
					const gchar* _tmp26_ = NULL;
					BoxesLibvirtSystemVMImporter* _tmp27_ = NULL;
					BoxesLibvirtSystemVMImporter* _tmp28_ = NULL;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
					_tmp25_ = boxes_collection_item_get_name ((BoxesCollectionItem*) machine);
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
					_tmp26_ = _tmp25_;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
					g_debug ("libvirt-broker.vala:64: Continuing import of '%s', ..", _tmp26_);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
					_tmp27_ = boxes_libvirt_system_vm_importer_new_for_import_completion (machine);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
					_tmp28_ = _tmp27_;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
					_boxes_vm_creator_unref0 (_tmp28_);
#line 1045 "libvirt-broker.c"
				}
			}
		}
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_g_object_unref0 (config);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_g_object_unref0 (machine);
#line 1053 "libvirt-broker.c"
	}
	goto __finally13;
	__catch13_g_error:
	{
		GError* _error_ = NULL;
		BoxesCollectionSource* _tmp29_ = NULL;
		gchar* _tmp30_ = NULL;
		gchar* _tmp31_ = NULL;
		gchar* _tmp32_ = NULL;
		GError* _tmp33_ = NULL;
		const gchar* _tmp34_ = NULL;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_error_ = _inner_error_;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_inner_error_ = NULL;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_tmp29_ = source;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_tmp30_ = boxes_collection_source_get_name (_tmp29_);
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_tmp31_ = _tmp30_;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_tmp32_ = _tmp31_;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_tmp33_ = _error_;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_tmp34_ = _tmp33_->message;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_warning ("libvirt-broker.vala:68: Failed to create source '%s': %s", _tmp32_, _tmp34_);
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_g_free0 (_tmp32_);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_g_error_free0 (_error_);
#line 1087 "libvirt-broker.c"
	}
	__finally13:
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	if (_inner_error_ != NULL) {
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_clear_error (&_inner_error_);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		return;
#line 1098 "libvirt-broker.c"
	}
}


static void boxes_libvirt_broker_real_add_source_data_free (gpointer _data) {
	BoxesLibvirtBrokerAddSourceData* _data_;
	_data_ = _data;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_slice_free (BoxesLibvirtBrokerAddSourceData, _data_);
#line 1110 "libvirt-broker.c"
}


static void boxes_libvirt_broker_real_add_source (BoxesBroker* base, BoxesCollectionSource* source, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesLibvirtBroker * self;
	BoxesLibvirtBrokerAddSourceData* _data_;
	BoxesLibvirtBroker* _tmp0_ = NULL;
	BoxesCollectionSource* _tmp1_ = NULL;
	BoxesCollectionSource* _tmp2_ = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	self = (BoxesLibvirtBroker*) base;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_ = g_slice_new0 (BoxesLibvirtBrokerAddSourceData);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_libvirt_broker_real_add_source);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_libvirt_broker_real_add_source_data_free);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->self = _tmp0_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp1_ = source;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_object_unref0 (_data_->source);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->source = _tmp2_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	boxes_libvirt_broker_real_add_source_co (_data_);
#line 1142 "libvirt-broker.c"
}


static void boxes_libvirt_broker_real_add_source_finish (BoxesBroker* base, GAsyncResult* _res_) {
	BoxesLibvirtBrokerAddSourceData* _data_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 1150 "libvirt-broker.c"
}


static Block21Data* block21_data_ref (Block21Data* _data21_) {
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_atomic_int_inc (&_data21_->_ref_count_);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	return _data21_;
#line 1159 "libvirt-broker.c"
}


static void block21_data_unref (void * _userdata_) {
	Block21Data* _data21_;
	_data21_ = (Block21Data*) _userdata_;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	if (g_atomic_int_dec_and_test (&_data21_->_ref_count_)) {
#line 1168 "libvirt-broker.c"
		BoxesLibvirtBroker * self;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		self = _data21_->self;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_g_object_unref0 (_data21_->source);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_g_object_unref0 (self);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_slice_free (Block21Data, _data21_);
#line 1178 "libvirt-broker.c"
	}
}


static void boxes_libvirt_broker_add_source_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesLibvirtBrokerAddSourceData* _data_;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_ = _user_data_;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_source_object_ = source_object;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_res_ = _res_;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	boxes_libvirt_broker_real_add_source_co (_data_);
#line 1193 "libvirt-broker.c"
}


static void _vala_GVirStoragePoolInfo_free (GVirStoragePoolInfo* self) {
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_boxed_free (gvir_storage_pool_info_get_type (), self);
#line 1200 "libvirt-broker.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_list_free (self);
#line 1209 "libvirt-broker.c"
}


static void __lambda64_ (BoxesLibvirtBroker* self, GVirConnection* connection, GVirDomain* domain) {
	BoxesLibvirtMachine* machine = NULL;
	GVirDomain* _tmp0_ = NULL;
	gconstpointer _tmp1_ = NULL;
	BoxesLibvirtMachine* _tmp2_ = NULL;
	BoxesLibvirtMachine* _tmp3_ = NULL;
	BoxesApp* _tmp4_ = NULL;
	BoxesLibvirtMachine* _tmp5_ = NULL;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_return_if_fail (connection != NULL);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_return_if_fail (domain != NULL);
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp0_ = domain;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp1_ = g_object_get_data ((GObject*) _tmp0_, "machine");
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp2_ = _g_object_ref0 ((BoxesLibvirtMachine*) _tmp1_);
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	machine = _tmp2_;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp3_ = machine;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	if (_tmp3_ == NULL) {
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_g_object_unref0 (machine);
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		return;
#line 1241 "libvirt-broker.c"
	}
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp4_ = boxes_app_app;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp5_ = machine;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	boxes_app_delete_machine (_tmp4_, (BoxesMachine*) _tmp5_, FALSE);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_object_unref0 (machine);
#line 1251 "libvirt-broker.c"
}


static void ___lambda64__gvir_connection_domain_removed (GVirConnection* _sender, GVirDomain* dom, gpointer self) {
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	__lambda64_ (self, _sender, dom);
#line 1258 "libvirt-broker.c"
}


static void __lambda65_ (Block21Data* _data21_, GVirConnection* connection, GVirDomain* domain) {
	BoxesLibvirtBroker * self;
	GVirDomain* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	BoxesCollectionSource* _tmp2_ = NULL;
	GVirConnection* _tmp3_ = NULL;
	GVirDomain* _tmp4_ = NULL;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	self = _data21_->self;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_return_if_fail (connection != NULL);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_return_if_fail (domain != NULL);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp0_ = domain;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp1_ = gvir_domain_get_name (_tmp0_);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_debug ("libvirt-broker.vala:107: New domain '%s'", _tmp1_);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp2_ = _data21_->source;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp3_ = connection;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp4_ = domain;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	boxes_libvirt_broker_try_add_new_domain (self, _tmp2_, _tmp3_, _tmp4_);
#line 1289 "libvirt-broker.c"
}


static void ___lambda65__gvir_connection_domain_added (GVirConnection* _sender, GVirDomain* dom, gpointer self) {
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	__lambda65_ (self, _sender, dom);
#line 1296 "libvirt-broker.c"
}


static gboolean boxes_libvirt_broker_real_add_source_co (BoxesLibvirtBrokerAddSourceData* _data_) {
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	switch (_data_->_state_) {
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		case 0:
#line 1305 "libvirt-broker.c"
		goto _state_0;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		case 1:
#line 1309 "libvirt-broker.c"
		goto _state_1;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		case 2:
#line 1313 "libvirt-broker.c"
		goto _state_2;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		case 3:
#line 1317 "libvirt-broker.c"
		goto _state_3;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		case 4:
#line 1321 "libvirt-broker.c"
		goto _state_4;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		case 5:
#line 1325 "libvirt-broker.c"
		goto _state_5;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		case 6:
#line 1329 "libvirt-broker.c"
		goto _state_6;
		default:
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_assert_not_reached ();
#line 1334 "libvirt-broker.c"
	}
	_state_0:
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_data21_ = g_slice_new0 (Block21Data);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_data21_->_ref_count_ = 1;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_data21_->self = g_object_ref (_data_->self);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp0_ = NULL;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp0_ = _data_->source;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_object_unref0 (_data_->_data21_->source);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_data21_->source = _data_->_tmp0_;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_data21_->_async_data_ = _data_;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp1_ = NULL;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp1_ = _data_->self->priv->connections;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp2_ = NULL;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp2_ = _data_->_data21_->source;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp3_ = NULL;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp3_ = boxes_collection_source_get_name (_data_->_tmp2_);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp4_ = NULL;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp4_ = _data_->_tmp3_;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp5_ = NULL;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp5_ = _data_->_tmp4_;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp6_ = NULL;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp6_ = g_hash_table_lookup (_data_->_tmp1_, _data_->_tmp5_);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp7_ = FALSE;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp7_ = ((GVirConnection*) _data_->_tmp6_) != NULL;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_free0 (_data_->_tmp5_);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	if (_data_->_tmp7_) {
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		block21_data_unref (_data_->_data21_);
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_data21_ = NULL;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		if (_data_->_state_ == 0) {
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1393 "libvirt-broker.c"
		} else {
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1397 "libvirt-broker.c"
		}
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_object_unref (_data_->_async_result);
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		return FALSE;
#line 1403 "libvirt-broker.c"
	}
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp8_ = NULL;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp8_ = _data_->_data21_->source;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp9_ = NULL;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp9_ = boxes_collection_source_get_uri (_data_->_tmp8_);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp10_ = NULL;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp10_ = _data_->_tmp9_;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp11_ = NULL;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp11_ = _data_->_tmp10_;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp12_ = NULL;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp12_ = gvir_connection_new (_data_->_tmp11_);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp13_ = NULL;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp13_ = _data_->_tmp12_;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_free0 (_data_->_tmp11_);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->connection = _data_->_tmp13_;
#line 1433 "libvirt-broker.c"
	{
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp14_ = NULL;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp14_ = _data_->connection;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_state_ = 1;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		gvir_connection_open_async (_data_->_tmp14_, NULL, boxes_libvirt_broker_add_source_ready, _data_);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		return FALSE;
#line 1445 "libvirt-broker.c"
		_state_1:
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		gvir_connection_open_finish (_data_->_tmp14_, _data_->_res_, &_data_->_inner_error_);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		if (_data_->_inner_error_ != NULL) {
#line 1451 "libvirt-broker.c"
			goto __catch14_g_error;
		}
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp15_ = NULL;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp15_ = _data_->connection;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_state_ = 2;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		gvir_connection_fetch_domains_async (_data_->_tmp15_, NULL, boxes_libvirt_broker_add_source_ready, _data_);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		return FALSE;
#line 1464 "libvirt-broker.c"
		_state_2:
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		gvir_connection_fetch_domains_finish (_data_->_tmp15_, _data_->_res_, &_data_->_inner_error_);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		if (_data_->_inner_error_ != NULL) {
#line 1470 "libvirt-broker.c"
			goto __catch14_g_error;
		}
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp16_ = NULL;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp16_ = _data_->connection;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_state_ = 3;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		gvir_connection_fetch_storage_pools_async (_data_->_tmp16_, NULL, boxes_libvirt_broker_add_source_ready, _data_);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		return FALSE;
#line 1483 "libvirt-broker.c"
		_state_3:
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		gvir_connection_fetch_storage_pools_finish (_data_->_tmp16_, _data_->_res_, &_data_->_inner_error_);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		if (_data_->_inner_error_ != NULL) {
#line 1489 "libvirt-broker.c"
			goto __catch14_g_error;
		}
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp17_ = NULL;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp17_ = _data_->connection;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp18_ = NULL;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp18_ = boxes_get_storage_pool (_data_->_tmp17_);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->pool = _data_->_tmp18_;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp19_ = NULL;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp19_ = _data_->pool;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		if (_data_->_tmp19_ != NULL) {
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp21_ = NULL;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp21_ = _data_->pool;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp22_ = NULL;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp22_ = gvir_storage_pool_get_info (_data_->_tmp21_, &_data_->_inner_error_);
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp20_ = _data_->_tmp22_;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			if (_data_->_inner_error_ != NULL) {
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_g_object_unref0 (_data_->pool);
#line 1522 "libvirt-broker.c"
				goto __catch14_g_error;
			}
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp23_ = NULL;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp23_ = _data_->_tmp20_;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp24_ = 0;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp24_ = _data_->_tmp23_->state;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp25_ = FALSE;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp25_ = _data_->_tmp24_ == GVIR_STORAGE_POOL_STATE_INACTIVE;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			__vala_GVirStoragePoolInfo_free0 (_data_->_tmp23_);
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			if (_data_->_tmp25_) {
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_data_->_tmp26_ = NULL;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_data_->_tmp26_ = _data_->pool;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_data_->_state_ = 4;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				gvir_storage_pool_start_async (_data_->_tmp26_, (guint) 0, NULL, boxes_libvirt_broker_add_source_ready, _data_);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				return FALSE;
#line 1551 "libvirt-broker.c"
				_state_4:
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				gvir_storage_pool_start_finish (_data_->_tmp26_, _data_->_res_, &_data_->_inner_error_);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				if (_data_->_inner_error_ != NULL) {
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
					_g_object_unref0 (_data_->pool);
#line 1559 "libvirt-broker.c"
					goto __catch14_g_error;
				}
			}
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp27_ = NULL;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp27_ = _data_->pool;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_state_ = 5;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			gvir_storage_pool_refresh_async (_data_->_tmp27_, NULL, boxes_libvirt_broker_add_source_ready, _data_);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			return FALSE;
#line 1573 "libvirt-broker.c"
			_state_5:
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			gvir_storage_pool_refresh_finish (_data_->_tmp27_, _data_->_res_, &_data_->_inner_error_);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			if (_data_->_inner_error_ != NULL) {
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_g_object_unref0 (_data_->pool);
#line 1581 "libvirt-broker.c"
				goto __catch14_g_error;
			}
		}
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_g_object_unref0 (_data_->pool);
#line 1587 "libvirt-broker.c"
	}
	goto __finally14;
	__catch14_g_error:
	{
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_inner_error_ = NULL;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp28_ = NULL;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp28_ = _data_->_error_;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp29_ = NULL;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp29_ = _data_->_tmp28_->message;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_warning ("libvirt-broker.vala:90: %s", _data_->_tmp29_);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_g_error_free0 (_data_->_error_);
#line 1608 "libvirt-broker.c"
	}
	__finally14:
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	if (_data_->_inner_error_ != NULL) {
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_g_object_unref0 (_data_->connection);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		block21_data_unref (_data_->_data21_);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_data21_ = NULL;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_clear_error (&_data_->_inner_error_);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		return FALSE;
#line 1625 "libvirt-broker.c"
	}
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp30_ = NULL;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp30_ = _data_->self->priv->connections;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp31_ = NULL;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp31_ = _data_->_data21_->source;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp32_ = NULL;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp32_ = boxes_collection_source_get_name (_data_->_tmp31_);
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp33_ = NULL;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp33_ = _data_->_tmp32_;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp34_ = NULL;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp34_ = _data_->connection;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp35_ = NULL;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp35_ = _g_object_ref0 (_data_->_tmp34_);
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_hash_table_insert (_data_->_tmp30_, _data_->_tmp33_, _data_->_tmp35_);
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp36_ = NULL;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp36_ = _data_->connection;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp37_ = NULL;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp37_ = gvir_connection_get_domains (_data_->_tmp36_);
#line 1661 "libvirt-broker.c"
	{
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->domain_collection = _data_->_tmp37_;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		for (_data_->domain_it = _data_->domain_collection; _data_->domain_it != NULL; _data_->domain_it = _data_->domain_it->next) {
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp38_ = NULL;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp38_ = _g_object_ref0 ((GVirDomain*) _data_->domain_it->data);
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->domain = _data_->_tmp38_;
#line 1673 "libvirt-broker.c"
			{
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_data_->_tmp39_ = NULL;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_data_->_tmp39_ = _data_->_data21_->source;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_data_->_tmp40_ = NULL;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_data_->_tmp40_ = _data_->connection;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_data_->_tmp41_ = NULL;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_data_->_tmp41_ = _data_->domain;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				boxes_libvirt_broker_try_add_existing_domain (_data_->self, _data_->_tmp39_, _data_->_tmp40_, _data_->_tmp41_);
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_g_object_unref0 (_data_->domain);
#line 1691 "libvirt-broker.c"
			}
		}
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		__g_list_free__g_object_unref0_0 (_data_->domain_collection);
#line 1696 "libvirt-broker.c"
	}
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp42_ = NULL;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp42_ = _data_->connection;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_signal_connect_object (_data_->_tmp42_, "domain-removed", (GCallback) ___lambda64__gvir_connection_domain_removed, _data_->self, 0);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp43_ = NULL;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp43_ = _data_->connection;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_signal_connect_data (_data_->_tmp43_, "domain-added", (GCallback) ___lambda65__gvir_connection_domain_added, block21_data_ref (_data_->_data21_), (GClosureNotify) block21_data_unref, 0);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp44_ = NULL;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp44_ = _data_->_data21_->source;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_state_ = 6;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	BOXES_BROKER_CLASS (boxes_libvirt_broker_parent_class)->add_source (G_TYPE_CHECK_INSTANCE_CAST (_data_->self, BOXES_TYPE_BROKER, BoxesBroker), _data_->_tmp44_, boxes_libvirt_broker_add_source_ready, _data_);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	return FALSE;
#line 1720 "libvirt-broker.c"
	_state_6:
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	BOXES_BROKER_CLASS (boxes_libvirt_broker_parent_class)->add_source_finish (G_TYPE_CHECK_INSTANCE_CAST (_data_->self, BOXES_TYPE_BROKER, BoxesBroker), _data_->_res_);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_object_unref0 (_data_->connection);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	block21_data_unref (_data_->_data21_);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_data21_ = NULL;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	if (_data_->_state_ == 0) {
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1734 "libvirt-broker.c"
	} else {
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1738 "libvirt-broker.c"
	}
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_object_unref (_data_->_async_result);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	return FALSE;
#line 1744 "libvirt-broker.c"
}


static void boxes_libvirt_broker_class_init (BoxesLibvirtBrokerClass * klass) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	boxes_libvirt_broker_parent_class = g_type_class_peek_parent (klass);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_type_class_add_private (klass, sizeof (BoxesLibvirtBrokerPrivate));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	BOXES_BROKER_CLASS (klass)->add_source = boxes_libvirt_broker_real_add_source;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	BOXES_BROKER_CLASS (klass)->add_source_finish = boxes_libvirt_broker_real_add_source_finish;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_libvirt_broker_finalize;
#line 1759 "libvirt-broker.c"
}


static void boxes_libvirt_broker_instance_init (BoxesLibvirtBroker * self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	self->priv = BOXES_LIBVIRT_BROKER_GET_PRIVATE (self);
#line 1766 "libvirt-broker.c"
}


static void boxes_libvirt_broker_finalize (GObject* obj) {
	BoxesLibvirtBroker * self;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_LIBVIRT_BROKER, BoxesLibvirtBroker);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_hash_table_unref0 (self->priv->connections);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	G_OBJECT_CLASS (boxes_libvirt_broker_parent_class)->finalize (obj);
#line 1778 "libvirt-broker.c"
}


GType boxes_libvirt_broker_get_type (void) {
	static volatile gsize boxes_libvirt_broker_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_libvirt_broker_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesLibvirtBrokerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_libvirt_broker_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesLibvirtBroker), 0, (GInstanceInitFunc) boxes_libvirt_broker_instance_init, NULL };
		GType boxes_libvirt_broker_type_id;
		boxes_libvirt_broker_type_id = g_type_register_static (BOXES_TYPE_BROKER, "BoxesLibvirtBroker", &g_define_type_info, 0);
		g_once_init_leave (&boxes_libvirt_broker_type_id__volatile, boxes_libvirt_broker_type_id);
	}
	return boxes_libvirt_broker_type_id__volatile;
}



